summaryrefslogtreecommitdiffstats
path: root/src/usr/hwas/test
diff options
context:
space:
mode:
authorMatt Derksen <mderkse1@us.ibm.com>2017-09-13 08:58:27 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-10-15 16:26:48 -0400
commita5d19110fd5dad891f8fe20c260fb7fb23051822 (patch)
treeeeeecdc372c8e6294fa74ed152e981b5c680fd20 /src/usr/hwas/test
parent54a809824656603dad56d67c8cab8946bfa43ecb (diff)
downloadtalos-hostboot-a5d19110fd5dad891f8fe20c260fb7fb23051822.tar.gz
talos-hostboot-a5d19110fd5dad891f8fe20c260fb7fb23051822.zip
Fix parent of OBUS_BRICK
- remove OPTICS_CONFIG_MODE from obus brick targets - remove FAPI_POS from cumulus obus bricks Change-Id: I7248bcf39526378fa5b8322a331beeeb33d4d2a4 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/46141 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com> Reviewed-by: Prachi Gupta <pragupta@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/hwas/test')
-rw-r--r--src/usr/hwas/test/hwas1test.H11
1 files changed, 8 insertions, 3 deletions
diff --git a/src/usr/hwas/test/hwas1test.H b/src/usr/hwas/test/hwas1test.H
index 4b1e9ccd0..b11dcfad3 100644
--- a/src/usr/hwas/test/hwas1test.H
+++ b/src/usr/hwas/test/hwas1test.H
@@ -1652,14 +1652,19 @@ public:
case TYPE_OBUS_BRICK:
{
//Two cases here:
//OBRICK==SMP --> Target should be present regardless of PG
//OBRICK!=SMP --> Target should follow PG
//marking PG bad
pgData[VPD_CP00_PG_N3_INDEX] |=
(uint16_t)VPD_CP00_PG_N3_NPU;
+ // get parent OBUS and check OPTICS_CONFIG_MODE
+ auto obusType = TARGETING::TYPE_OBUS;
+ TARGETING::Target* l_obus_ptr =
+ const_cast<TARGETING::Target*>(
+ getParent(pDesc, obusType));
ATTR_OPTICS_CONFIG_MODE_type config_mode =
- pDesc->getAttr<ATTR_OPTICS_CONFIG_MODE>();
+ l_obus_ptr->getAttr<ATTR_OPTICS_CONFIG_MODE>();
if (OPTICS_CONFIG_MODE_SMP == config_mode)
{
OpenPOWER on IntegriCloud
@@ -1652,14 +1652,19 @@ public:
{
//Two cases here:
- //OBRICK==SMP --> Target should be present regardless of PG
- //OBRICK!=SMP --> Target should follow PG
+ //OBUS==SMP --> Target should be present regardless of PG
+ //OBUS!=SMP --> Target should follow PG
//marking PG bad
pgData[VPD_CP00_PG_N3_INDEX] |=